# $NetBSD: doc.docbook.mk,v 1.29 2017/02/19 23:15:10 wiz Exp $

#
# include default settings and /etc/mk.conf first
#
.include "web.prefs.mk"

BSD_PKG_MK=			# defined
.include <bsd.own.mk>

UNAME!=		uname -s

.if ${UNAME} == FreeBSD
LOCALBASE?=	/usr/local
PREFIX?=	${LOCALBASE}
SGML_PREFIX?=	${PREFIX}/share/sgml
XML_PREFIX?=	${PREFIX}/share/xml
XSL_PREFIX?=	${PREFIX}/share/xsl
XML_DECL?=	${SGML_PREFIX}/docbook/dsssl/modular/dtds/decls/xml.dcl
DBX_SGML_CATALOG?=	${SGML_PREFIX}/catalog
DBX_XML_CATALOG?=	${XML_PREFIX}/catalog
DBX_XML_DTD?=	${XML_PREFIX}/docbook/4.2/docbookx.dtd
DBX_XSL_HTML?=	${XSL_PREFIX}/docbook/html/docbook.xsl
DBX_XSL_HTMLCHUNK?=	${XSL_PREFIX}/docbook/html/chunk.xsl
.elif ${UNAME} == OpenBSD
LOCALBASE?=	/usr/local
PREFIX?=	${LOCALBASE}
SGML_PREFIX?=	${PREFIX}/share/sgml
XML_PREFIX?=	${PREFIX}/share/xml
XSL_PREFIX?=	${PREFIX}/share/xsl
XML_DECL?=	${SGML_PREFIX}/docbook/dsssl/modular/dtds/decls/xml.dcl
DBX_SGML_CATALOG?=	${XML_PREFIX}/docbook/4.2/catalog
DBX_XML_CATALOG?=	${XML_PREFIX}/docbook/4.2/catalog.xml
DBX_XML_DTD?=	${XML_PREFIX}/docbook/4.2/docbookx.dtd
DBX_XSL_HTML?=	${XSL_PREFIX}/docbook/html/docbook.xsl
DBX_XSL_HTMLCHUNK?=	${XSL_PREFIX}/docbook/html/chunk.xsl
.else
LOCALBASE?=     /usr/pkg
.if exists(${LOCALBASE}/sbin/pkg_info)
PKG_INFO?=	${LOCALBASE}/sbin/pkg_info
.endif
PKG_INFO?=	/usr/sbin/pkg_info
PREFIX?=        ${LOCALBASE}
SGML_PREFIX?=	${PREFIX}/share/sgml
XML_PREFIX?=	${PREFIX}/share/xml
XSL_PREFIX?=	${PREFIX}/share/xsl
XML_DECL?=	${SGML_PREFIX}/docbook/dsssl/modular/dtds/decls/xml.dcl
DBX_SGML_CATALOG?=	${SGML_PREFIX}/docbook/4.2/catalog
DBX_XML_CATALOG?=	${SGML_PREFIX}/docbook/4.2/catalog.xml
.if exists(${XML_PREFIX}/docbook/docbookx.dtd)	# textproc/docbook-xml<4.4
DBX_XML_DTD?=	${XML_PREFIX}/docbook/docbookx.dtd
.else	# textproc/docbook-xml>=4.4
DBX_XML_DTD?=	${XML_PREFIX}/docbook/4.2/docbookx.dtd
.endif
DBX_XSL_HTML?=	${XSL_PREFIX}/docbook/html/docbook.xsl
DBX_XSL_HTMLCHUNK?=	${XSL_PREFIX}/docbook/html/chunk.xsl
REQPKGS_COMMON=	docbook>=4.0 docbook-xml>=4.0 opensp>=1.5
REQPKGS_XSL=	libxslt>=1.0.30 docbook-xsl>=1.62.4
REQPKGS_DSSSL=	openjade>=1.3.2 dsssl-docbook-modular>=1.54
REQPKGS_PRINT?=	tex-jadetex>=3.13 ghostscript>=7.05
REQPKGS_ASCII=	w3m>=0.4
.if defined(NO_TIDY) && empty(NO_TIDY:M[Yy][Ee][Ss])
REQPKGS_HTML=	tidy-[0-9]*
.endif
REQPKGS=	${REQPKGS_COMMON}
.BEGIN:
	@echo -n "[Checking tools for typesetting..."
	@(missing=""; \
	for T in ${REQPKGS:S,<,\\<,:S,>,\\>,}; do \
		${PKG_INFO} -e $${T} > /dev/null 2>&1; \
		if test $$? -ne 0 ; then \
			missing="$${missing} $${T}";\
		fi; \
	done; \
	case $${missing} in \
	"")	echo "OK]" ;; \
	*)	echo "NG]"; \
		echo "===> ERROR: The following packages are missing for typesetting:"; \
		for T in $${missing}; do \
			echo "      - $${T}"; \
		done; \
		echo "  Make sure to install the latest package of meta-pkgs/netbsd-doc"; \
		echo "  via pkgsrc.  For printable formats, meta-pkgs/netbsd-doc-print is needed."; \
		/usr/bin/false ;; \
	esac)
.endif

.if exists(${.CURDIR}/share/catalog)
CATALOGS+= ${.CURDIR}/share/catalog
.endif
CATALOGS+= ${WEB_PREFIX}/share/xml/catalog
CATALOGS+= ${SGML_PREFIX}/catalog
CATALOGS+= ${SGML_PREFIX}/docbook/dsssl/modular/catalog
CATALOGS+= ${DBX_SGML_CATALOG}

SGML_CATALOGS= ${CATALOGS:S/^/-c /g}

XML_CATALOGS=	${XML_CATALOG_FILES}

XML_CATALOG_FILES=	file://${WEB_PREFIX}/${DOCLANG}/share/xml/catalog.xml \
			file://${WEB_PREFIX}/share/xml/catalog.xml \
			file://${WEB_PREFIX}/share/xml/catalog-common.xml
.if defined(PKG_SYSCONFDIR.xmlcatmgr)
XML_CATALOG_FILES+=	file://${PKG_SYSCONFDIR.xmlcatmgr}/xml/catalog
.elif defined(PKG_SYSCONFBASE)
XML_CATALOG_FILES+=	file://${PKG_SYSCONFBASE}/xml/catalog
.else
XML_CATALOG_FILES+=	file://${LOCALBASE}/etc/xml/catalog
.endif

DOCLANG?=	en

XML_ENCODING?=	iso-8859-1
SP_ENCODING?=	iso-8859-1
SX_ENCODING?=	iso-8859-1

SED?=		/usr/bin/sed
CAT?=		/bin/cat

PS2PDF?=	${PREFIX}/bin/ps2pdf
DVIPS?=		${PREFIX}/bin/dvips

W3M_BIN?=	${PREFIX}/bin/w3m
W3M_OPTS=	-dump ${XML_ENCODING:S/^/-O /} -no-graph ${W3M_FLAGS}	
W3M=		${W3M_BIN} ${W3M_OPTS}

TIDY_BIN?=	${PREFIX}/bin/tidy
.if ${UNAME} == NetBSD || ${UNAME} == OpenBSD
TIDY_OPTS?= -i -m -f /dev/null -asxml ${TIDYFLAGS}
.elif ${UNAME} == FreeBSD
TIDY_OPTS?= -i -m -preserve -f /dev/null -asxml ${TIDYFLAGS}
.endif
TIDY?=		env HTML_TIDY=/dev/null ${TIDY_BIN} ${TIDY_OPTS} ${TIDY_FLAGS}

MANIFEST?=	HTML.manifest
HTML_INDEX?=	index.html

DOCBOOKCSS=	${WEB_PREFIX}/share/xml/docbook.css

_REAL_WEB_PREFIX!=	cd ${WEB_PREFIX}; /bin/pwd
_REL_WEB_PREFIX!=	cd ${.CURDIR}; /bin/pwd
WEB_PREFIX_RELATIVE:=	${_REL_WEB_PREFIX:S,^${_REAL_WEB_PREFIX}/,,:C,.[^/]+/?,../,g:S,/$,,}

CLEANFILES+=	${MANIFEST}
CLEANFILES+=	${SXERR}

.MAIN: all

all pdf html html-split ascii: build

.if make(html)
FORMATS?=	html
STYLE_TYPE?=	xsl
.elif make(html-split)
FORMATS?=	html-split
STYLE_TYPE?=	xsl
.elif make(ps)
FORMATS?=	ps
STYLE_TYPE?=	dsssl
.elif make(pdf)
FORMATS?=	pdf
STYLE_TYPE?=	dsssl
.elif make(ascii)
FORMATS?=	ascii
STYLE_TYPE?=	xsl
.endif
FORMATS?=	html-split
STYLE_TYPE?=	xsl

.for F in ${FORMATS}
build: build-${F}
.endfor

build-html: ${DOC}.html
build-html-split: ${HTML_INDEX}
build-ps: ${DOC}.ps
build-pdf: ${DOC}.pdf
build-ascii: ${DOC}.txt

clean:
	if [ -r ${MANIFEST} ]; then rm -f `cat ${MANIFEST}`; fi
	rm -f ${CLEANFILES}

cleandir: clean
	rm -f default-chunk.xml default.xml
	rm -f *~ core *.core *.rtf *.html *.fot *.log
	rm -f *.aux *.dvi *.tex *.out *.ps *.pdf *.txt

.SUFFIXES:
.SUFFIXES: .tex .xml .sgml .html .rtf .ps .pdf .txt

.PHONY: all clean cleandir install lint
.PHONY: html html-split ps pdf ascii
.PHONY: build-html build-ps build-pdf build-ascii

STYLE_TYPE?= xsl

.include <bsd.obj.mk>

.if ${STYLE_TYPE} == dsssl
REQPKGS+=	${REQPKGS_DSSSL}
.include "${.PARSEDIR}/doc.docbook.dsssl.mk"
.else
REQPKGS+=	${REQPKGS_XSL}
.include "${.PARSEDIR}/doc.docbook.xsl.mk"
.endif

.if ${FORMATS:Mascii} == ascii
REQPKGS+=	${REQPKGS_ASCII}
.endif
.if ${FORMATS:Mhtml} == html || ${FORMATS:Mhtml-split}
REQPKGS+=	${REQPKGS_HTML}
.endif
.if ${FORMATS:Mps} == ps || ${FORMATS:Mpdf} == pdf
REQPKGS+=	${REQPKGS_PRINT}
.endif

.include "${.PARSEDIR}/doc.install.mk"
